from setuptools import find_packages, setup

setup(
    name='teachera',
    version="9.9",
    packages=find_packages(),
    description='Dependency confusion demo library for learning purposes',
    author='Practical DevSecOps',
    author_email='info@practical-devsecops.com',
    py_modules=['teachera']
)